@@ -118,6 +118,21 @@ def persist_messages(collection: StandardCollection, messages: io.TextIOWrapper,
                                     f' Only `{kps[0]}` will be considered.')
                     _key = str(rec[kps[0]]).strip()
 
+                    # Appending _ to keys inorder for preserving values of reserved keys in source data
+                    reserved_keys = ['_key', '_id', '_rev']
+                    if kps[0] == '_key':
+                        reserved_keys.remove('_key')
+
+                    for reserved_key in reserved_keys:
+                        if rec.get(reserved_key):
+                            new_key = "_" + reserved_key
+                            while True:
+                                if rec.get(new_key):
+                                    new_key = "_" + new_key
+                                else:
+                                    break
+                            rec[new_key] = rec.pop(reserved_key)
+
                     if not (1 <= len(_key) <= 254 and bool(re.match("^[-_!\$%'\(\)\*\+,\.:;=@a-zA-Z0-9]+$", _key))):
                         hashed_key = hashlib.sha256(_key.encode('utf-8'))
                         _key = hashed_key.hexdigest()
